#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# test_agi.py für Asterisk
# Dieses Skript ruft Daten vom Kostal-Wechselrichter ab und gibt sie per AGI aus.
# Es benötigt kostal_modbusquery.py im selben Verzeichnis.

import asterisk_agi as agi  # AGI-Module importieren
from kostal_modbusquery import kostal_modbusquery  # Kostal-Modul importieren

def main():
    # Initialisiert die AGI-Umgebung
    env = agi.init_env()

    # Kostal-Daten abrufen
    try:
        Kostalquery = kostal_modbusquery()  # Initialisiert die Kostal-Abfrage
        Kostalquery.run()  # Führt die Abfrage aus

        # Daten berechnen
        KostalVal = {elements[1]: elements[3] for elements in Kostalquery.KostalRegister}  # Dictionary erstellen
        TotalHomeconsumption = round(
            KostalVal['Home own consumption from battery'] +
            KostalVal['Home own consumption from grid'] +
            KostalVal['Home own consumption from PV'], 1
        )
        LeftSidePowerGeneration = round((KostalVal['Power DC1'] + KostalVal['Power DC2']), 1)
        BatteryCharge = round(KostalVal['Battery voltage'] * KostalVal['Actual battery charge -minus or discharge -plus current'], 1)
        PowertoGrid = round(KostalVal['Inverter Generation Power (actual)'] - TotalHomeconsumption, 1)

        # Abspielen der Ergebnisse
        agi.sayit("/usr/share/asterisk/sounds/eigene/kostal/Aktueller_Hausverbrauch_Watt_G711.org_")  # Hausverbrauch
        agi.saynumber(TotalHomeconsumption)  # Gesamtverbrauch ausgeben
        
        agi.sayit("/usr/share/asterisk/sounds/eigene/kostal/Ladezustand_Batteriespeicher_Prozent_G711.org_") 
        agi.saynumber(KostalVal['Act. state of charge'])
        
        agi.sayit("/usr/share/asterisk/sounds/eigene/kostal/Temperatur_Batteriespeicher_Celsius_G711.org_") 
        agi.saynumber(KostalVal['Battery temperature'])
        
        agi.sayit("/usr/share/asterisk/sounds/eigene/kostal/Solarzellen_Leistung_Watt_G711.org_") 
        agi.saynumber(LeftSidePowerGeneration)
        
        agi.sayit("/usr/share/asterisk/sounds/eigene/kostal/Momentanes_Laden_der_Batterie_Watt_G711.org_") 
        agi.saynumber(BatteryCharge)
        
        agi.sayit("/usr/share/asterisk/sounds/eigene/kostal/Momentane_Einspeisung_Watt_G711.org_") 
        agi.saynumber(PowertoGrid)
        
        agi.sayit("/usr/share/asterisk/sounds/eigene/kostal/good_bye_G711.org_") 


    except Exception as ex:
        agi.sayit("/usr/share/asterisk/sounds/eigene/kostal/error_G711.org_")
        agi.verbose(f"Error: {str(ex)}", level=3)  # Fehler im Asterisk-Log anzeigen

if __name__ == "__main__":
    main()

